==> openjdk-17_17.0.16+8.orig.tar.xz: openjdk-17-17.0.16+8/src/hotspot/share/gc/g1/g1RegionsOnNodes.hpp <==
/*
 * Copyright (c) 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 *
 */

#ifndef SHARE_VM_GC_G1_G1REGIONS_HPP
#define SHARE_VM_GC_G1_G1REGIONS_HPP

#include "memory/allocation.hpp"

class G1NUMA;
class HeapRegion;

// Contains per node index region count
class G1RegionsOnNodes : public StackObj {
  volatile uint* _count_per_node;
  G1NUMA*        _numa;

public:
  G1RegionsOnNodes();

  ~G1RegionsOnNodes();

  // Increase _count_per_node for the node of given heap region and returns node index.
  uint add(HeapRegion* hr);

  void clear();

  uint count(uint node_index) const;
};

#endif // SHARE_VM_GC_G1_G1REGIONS_HPP

==> openjdk-25_25.0.1+8.orig.tar.xz: openjdk-25-25.0.1+8/src/hotspot/share/gc/g1/g1RegionsOnNodes.hpp <==
/*
 * Copyright (c) 2019, 2024, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 *
 */

#ifndef SHARE_VM_GC_G1_G1REGIONS_HPP
#define SHARE_VM_GC_G1_G1REGIONS_HPP

#include "memory/allocation.hpp"

class G1NUMA;
class G1HeapRegion;

// Contains per node index region count
class G1RegionsOnNodes : public StackObj {
  volatile uint* _count_per_node;
  G1NUMA*        _numa;

public:
  G1RegionsOnNodes();

  ~G1RegionsOnNodes();

  // Increase _count_per_node for the node of given heap region and returns node index.
  uint add(G1HeapRegion* hr);

  void clear();

  uint count(uint node_index) const;
};

#endif // SHARE_VM_GC_G1_G1REGIONS_HPP
